==> aria2-0.8.1.tar.bz2: aria2-0.8.1/src/DelegatingPeerListProcessor.cc <==
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "DelegatingPeerListProcessor.h"

Peers DelegatingPeerListProcessor::extractPeer(const MetaEntry* peersEntry) {
  Peers peers;
  for(PeerListProcessors::iterator itr = processors.begin();
      itr != processors.end(); itr++) {
    PeerListProcessorHandle processor = *itr;
    if(processor->canHandle(peersEntry)) {
      Peers tempPeers = processor->extractPeer(peersEntry);
      copy(tempPeers.begin(), tempPeers.end(), back_inserter(peers));
      break;
    }
  }
  return peers;
}

bool DelegatingPeerListProcessor::canHandle(const MetaEntry* peersEntry) const {
  for(PeerListProcessors::const_iterator itr = processors.begin();
      itr != processors.end(); itr++) {
    if((*itr)->canHandle(peersEntry)) {
      return true;
    }
  }
}

==> aria2-1.2.0.tar.bz2: aria2-1.2.0/src/DelegatingPeerListProcessor.cc <==
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "DelegatingPeerListProcessor.h"

#include <algorithm>

#include "DefaultPeerListProcessor.h"
#include "CompactPeerListProcessor.h"
#include "Peer.h"
#include "bencode.h"

namespace aria2 {

DelegatingPeerListProcessor::DelegatingPeerListProcessor()
{
  {
    SharedHandle<PeerListProcessor> proc(new DefaultPeerListProcessor);
    processors.push_back(proc);
  }
  {
    SharedHandle<PeerListProcessor> proc(new CompactPeerListProcessor);
    processors.push_back(proc);
  }
}

DelegatingPeerListProcessor::~DelegatingPeerListProcessor() {}

void DelegatingPeerListProcessor::extractPeer
(std::deque<SharedHandle<Peer> >& peers, const bencode::BDE& peerData)
{
  for(std::deque<SharedHandle<PeerListProcessor> >::iterator itr =
	processors.begin(); itr != processors.end(); ++itr) {
    PeerListProcessorHandle processor = *itr;
    if(processor->canHandle(peerData)) {
      processor->extractPeer(peers, peerData);
      break;
    }
  }
}

bool DelegatingPeerListProcessor::canHandle(const bencode::BDE& peerData) const
{
  for(std::deque<SharedHandle<PeerListProcessor> >::const_iterator itr =
	processors.begin(); itr != processors.end(); ++itr) {
    if((*itr)->canHandle(peerData)) {
      return true;
    }
  }
  return false;
}

} // namespace aria2
